Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(536)

Unified Diff: src/ports/SkMemory_malloc.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ports/SkImageGenerator_skia.cpp ('k') | src/ports/SkOSFile_posix.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ports/SkMemory_malloc.cpp
diff --git a/src/ports/SkMemory_malloc.cpp b/src/ports/SkMemory_malloc.cpp
index f9836c0e0e03764a8d82673536993ff52b42943c..6ad01daca0fe0b58115ae0f0c76e9131862bc87b 100644
--- a/src/ports/SkMemory_malloc.cpp
+++ b/src/ports/SkMemory_malloc.cpp
@@ -19,8 +19,8 @@ static inline void sk_out_of_memory(size_t size) {
}
static inline void* throw_on_failure(size_t size, void* p) {
- if (size > 0 && p == NULL) {
- // If we've got a NULL here, the only reason we should have failed is running out of RAM.
+ if (size > 0 && p == nullptr) {
+ // If we've got a nullptr here, the only reason we should have failed is running out of RAM.
sk_out_of_memory(size);
}
return p;
« no previous file with comments | « src/ports/SkImageGenerator_skia.cpp ('k') | src/ports/SkOSFile_posix.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698